from tests.conftest import SOURCE_CODE_DIRECTORY


def test_compile(compiler, contract, project):
    compiler.compile([contract], base_path=SOURCE_CODE_DIRECTORY)
    assert project.get_contract(contract.stem)


def test_event_abi_migration(compiler):
    contract_with_event = SOURCE_CODE_DIRECTORY / "oz_proxy_lib.cairo"
    contract_type = compiler.compile([contract_with_event], base_path=SOURCE_CODE_DIRECTORY)[0]
    event_abi = [abi for abi in contract_type.abi if abi.type == "event"][0]
    assert len(event_abi.inputs) == 1
    assert event_abi.inputs[0].name == "implementation"
    assert event_abi.inputs[0].type == "felt"
    assert not event_abi.inputs[0].indexed



import os
from pathlib import Path

import ape
import pytest

PROJECT_DIRECTORY = Path(__file__).parent
SOURCE_CODE_DIRECTORY = PROJECT_DIRECTORY / "contracts"


@pytest.fixture(params=[p.name for p in SOURCE_CODE_DIRECTORY.iterdir()])
def contract(request):
    yield (SOURCE_CODE_DIRECTORY / request.param).absolute()


@pytest.fixture(scope="session", autouse=True)
def in_tests_directory():
    """
    Ensures tests are run from 'ape-cairo/tests/' directory.
    """
    start_path = Path.cwd()
    os.chdir(PROJECT_DIRECTORY)

    with ape.config.using_project(PROJECT_DIRECTORY):
        yield

    os.chdir(start_path)


@pytest.fixture(autouse=True)
def clean_cache():
    """
    Use this fixture to ensure a project
    does not have a cached compilation.
    """
    cache_file = PROJECT_DIRECTORY / ".build" / "__local__.json"
    if cache_file.exists():
        cache_file.unlink()

    yield

    if cache_file.exists():
        cache_file.unlink()


@pytest.fixture
def project():
    return ape.project


@pytest.fixture
def compiler():
    return ape.compilers.registered_compilers[".cairo"]



#!/usr/bin/env python
# -*- coding: utf-8 -*-
from setuptools import find_packages, setup  # type: ignore

extras_require = {
    "test": [  # `test` GitHub Action jobs uses this
        "pytest>=6.0,<7.0",  # Core testing package
        "pytest-xdist",  # multi-process runner
        "pytest-cov",  # Coverage analyzer plugin
        "hypothesis>=6.2.0,<7.0",  # Strategy-based fuzzer
    ],
    "lint": [
        "black>=22.3.0,<23.0",  # auto-formatter and linter
        "mypy>=0.910,<1.0",  # Static type analyzer
        "flake8>=3.9.2,<4.0",  # Style linter
        "isort>=5.10.1,<6.0",  # Import sorting linter
    ],
    "release": [  # `release` GitHub Action job uses this
        "setuptools",  # Installation tool
        "wheel",  # Packaging tool
        "twine",  # Package upload tool
    ],
    "dev": [
        "commitizen>=2.19,<2.20",  # Manage commits and publishing releases
        "pre-commit",  # Ensure that linters are run prior to committing
        "pytest-watch",  # `ptw` test watcher/runner
        "IPython",  # Console for interacting
        "ipdb",  # Debugger (Must use `export PYTHONBREAKPOINT=ipdb.set_trace`)
    ],
}

# NOTE: `pip install -e .[dev]` to install package
extras_require["dev"] = (
    extras_require["test"]
    + extras_require["lint"]
    + extras_require["release"]
    + extras_require["dev"]
)

with open("./README.md") as readme:
    long_description = readme.read()


setup(
    name="ape-cairo",
    use_scm_version=True,
    setup_requires=["setuptools_scm"],
    description="""ape-cairo: A compiler plugin for the cairo programming language""",
    long_description=long_description,
    long_description_content_type="text/markdown",
    author="ApeWorX Ltd.",
    author_email="admin@apeworx.io",
    url="https://github.com/ApeWorX/ape-cairo",
    include_package_data=True,
    install_requires=[
        "ecdsa",  # Not directly used, but part of install instructions for cairo-lang
        "fastecdsa",  # Not directly used, but part of install instructions for cairo-lang
        "sympy",  # Not directly used, but part of install instructions for cairo-lang
        "cairo-lang>=0.8.0,<0.9",
        "starknet.py>=0.2.0a0,<0.3.0",
        "eth-ape>=0.1.5,<0.2",
        "importlib-metadata ; python_version<'3.8'",
    ],  # NOTE: Add 3rd party libraries here
    python_requires=">=3.7.2,<4",
    extras_require=extras_require,
    py_modules=["ape_cairo"],
    license="Apache-2.0",
    zip_safe=False,
    keywords="ethereum",
    packages=find_packages(exclude=["tests", "tests.*"]),
    package_data={"ape_cairo": ["py.typed"]},
    classifiers=[
        "Development Status :: 4 - Beta",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: Apache Software License",
        "Natural Language :: English",
        "Operating System :: MacOS",
        "Operating System :: POSIX",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
    ],
)
